@@ -11,9 +11,10 @@ use overload '""' => \&_to_string, fallback => 1;
 use WWW::LogicBoxes::Types qw( Str NumberPhone );
 
 use Number::Phone;
+use Try::Tiny;
 use Carp;
 
-our $VERSION = '1.3.0'; # VERSION
+our $VERSION = '1.4.0'; # VERSION
 # ABSTRACT: Extendes Number::Phone to add 'number' functionatly (without country code)
 
 has '_number_phone_obj' => (
@@ -49,7 +50,18 @@ around BUILDARGS => sub {
     }
 
     if( ref $args eq '' ) {
-        return $class->$orig( _number_phone_obj => Number::Phone->new( $args ) );
+        # Compensate for cases where the country code is present in both the
+        # country code field AND the phone number itself
+        my $number_phone;
+        for ( my $offset = 0; $offset < length $args && $offset < 4; $offset++ ) {
+            $number_phone = Number::Phone->new( substr( $args, $offset ) );
+
+            if( $number_phone ) {
+                last;
+            }
+        }
+
+        return $class->$orig( _number_phone_obj => $number_phone );
     }
     elsif( ( ref $args ) =~ m/Number::Phone/ ) {
         return $class->$orig( _number_phone_obj => $args );
